# Papersurfer

Papersurfer, a new way to collaborate, organize and archive bibliographies.



![](screencast.gif)


Features:
- Export all or a subset of papers to a bibtex file (experimental)
- keywording, summary
- 
